@@ -85,6 +85,9 @@ ARGUMENT_RENAMES = {
     'lex-models.delete-intent-version.version': 'intent-version',
     'lex-models.delete-slot-type-version.version': 'slot-type-version',
     'lex-models.get-export.version': 'resource-version',
+    'license-manager.get-grant.version': 'grant-version',
+    'license-manager.delete-grant.version': 'grant-version',
+    'license-manager.get-license.version': 'license-version',
     'mobile.create-project.region': 'project-region',
     'rekognition.create-stream-processor.output': 'stream-processor-output',
     'eks.create-cluster.version': 'kubernetes-version',
@@ -92,6 +95,12 @@ ARGUMENT_RENAMES = {
     'eks.create-nodegroup.version': 'kubernetes-version',
     'eks.update-nodegroup-version.version': 'kubernetes-version',
     'schemas.*.version': 'schema-version',
+    'sagemaker.delete-image-version.version': 'version-number',
+    'sagemaker.describe-image-version.version': 'version-number',
+    'iotwireless.*.lo-ra-wan': 'lorawan',
+    'codepipeline.get-action-type.version': 'action-version',
+    'ecs.*.no-enable-execute-command': 'disable-execute-command',
+    'ecs.execute-command.no-interactive': 'non-interactive',
 }
 
 # Same format as ARGUMENT_RENAMES, but instead of renaming the arguments,
