@@ -108,7 +108,7 @@ RELEASE_LABEL = (
     ' the application versions and features available in that version.'
     ' For details about application versions and features available'
     ' in each release, see the Amazon EMR Release Guide:</p>'
-    '<p>https://docs.aws.amazon.com/emr/ReleaseGuide</p>'
+    '<p>https://docs.aws.amazon.com/emr/latest/ReleaseGuide</p>'
     '<p>Use <code>--release-label</code> only for Amazon EMR release version 4.0'
     ' and later. Use <code>--ami-version</code> for earlier versions.'
     ' You cannot specify both a release label and AMI version.</p>')
@@ -461,3 +461,13 @@ MANAGED_SCALING_POLICY = (
     'InstanceFleet cluster, the UnitType must be InstanceFleetUnits. For '
     'InstanceGroup clusters, the UnitType can be either VCPU or Instances.</p>'
 )
+
+PLACEMENT_GROUP_CONFIGS = (
+    '<p>Placement group configuration for an Amazon EMR ' 
+    'cluster. The configuration specifies the EC2 placement group ' 
+    'strategy associated with each EMR Instance Role.</p> ' 
+    '<p>Currently, we support placement group only for <code>MASTER</code> ' 
+    'role with <code>SPREAD</code> strategy by default. You can opt-in by '
+    'passing <code>--placement-group-configs InstanceRole=MASTER</code> '
+    'during cluster creation.</p>'
+)
